@@ -2,7 +2,7 @@ from pickle import dumps, loads
 from lzma import compress, decompress
 
 def dump(variable, path):
-    open(path, 'wb').write(lzma.compress(dumps(variable)))
+    open(path, 'wb').write(compress(dumps(variable)))
     
 def load(path):
-    return loads(lzma.decompress(open(path, 'rb').read()))
\ No newline at end of file
+    return loads(decompress(open(path, 'rb').read()))
\ No newline at end of file
